@@ -68,11 +68,14 @@ struct opl_operator {
 static struct sim_ef_info ef_db[] = {
 {	0x2F05, ROOTMF, BINARY, 0,	ALW,	PIN	},
 {	0x2F06, ROOTMF, RECORD, 0,	ALW,	PIN	},
-{	0x2FE2, ROOTMF, BINARY, 10,	ALW,	NEV 	},
+{	0x2FE2, ROOTMF, BINARY, 10,	ALW,	NEV	},
 {	0x4F20, 0x5F50, BINARY, 0,	PIN,	ADM	},
 {	0x6F05, 0x7F20, BINARY, 0,	ALW,	PIN	},
 {	0x6F06, 0x0000, RECORD, 0,	ALW,	ADM	},
+{	0x6F07, 0x0000, BINARY, 9,	PIN,	ADM	},
+{	0x6F14, 0x7F20, BINARY, 0,	PIN,	ADM	},
 {	0x6F15, 0x7F20, BINARY, 0,	PIN,	PIN	},
+{	0x6F18, 0x7F20, BINARY, 10,	PIN,	ADM	},
 {	0x6F2C, 0x7F20, BINARY, 16,	PIN,	PIN	},
 {	0x6F30, 0x7F20, BINARY, 0,	PIN,	PIN	},
 {	0x6F32, 0x7F20, BINARY, 0,	PIN,	ADM	},
@@ -1475,6 +1478,14 @@ gboolean sim_sst_is_active(unsigned char *efsst, unsigned char len,
 	return (efsst[index / 4] >> (((index % 4) * 2) + 1)) & 1;
 }
 
+gboolean sim_cphs_is_active(unsigned char *cphs, enum sim_cphs_service index)
+{
+	if (index >= 2 * 4u)
+		return FALSE;
+
+	return ((cphs[index / 4] >> ((index % 4) * 2)) & 3) == 3;
+}
+
 GSList *sim_parse_app_template_entries(const unsigned char *buffer, int len)
 {
 	GSList *ret = NULL;
